@@ -4,6 +4,7 @@ import functools
 import json
 import logging
 import os
+import uuid
 from typing import Any, Dict, List
 from urllib.parse import urlparse
 
@@ -209,15 +210,18 @@ class StudioWebProgressReporter:
         }
 
     @gracefully_handle_errors
-    async def create_eval_set_run(
+    async def create_eval_set_run_sw(
         self,
         eval_set_id: str,
         agent_snapshot: StudioWebAgentSnapshot,
         no_of_evals: int,
         evaluators: List[LegacyBaseEvaluator[Any]],
+        is_coded: bool = False,
     ) -> str:
         """Create a new evaluation set run in StudioWeb."""
-        spec = self._create_eval_set_run_spec(eval_set_id, agent_snapshot, no_of_evals)
+        spec = self._create_eval_set_run_spec(
+            eval_set_id, agent_snapshot, no_of_evals, is_coded
+        )
         response = await self._client.request_async(
             method=spec.method,
             url=spec.endpoint,
@@ -231,18 +235,19 @@ class StudioWebProgressReporter:
 
     @gracefully_handle_errors
     async def create_eval_run(
-        self, eval_item: AnyEvaluationItem, eval_set_run_id: str
+        self, eval_item: AnyEvaluationItem, eval_set_run_id: str, is_coded: bool = False
     ) -> str:
         """Create a new evaluation run in StudioWeb.
 
         Args:
             eval_item: Dictionary containing evaluation data
             eval_set_run_id: The ID of the evaluation set run
+            is_coded: Whether this is a coded evaluation (vs legacy)
 
         Returns:
             The ID of the created evaluation run
         """
-        spec = self._create_eval_run_spec(eval_item, eval_set_run_id)
+        spec = self._create_eval_run_spec(eval_item, eval_set_run_id, is_coded)
         response = await self._client.request_async(
             method=spec.method,
             url=spec.endpoint,
@@ -289,13 +294,25 @@ class StudioWebProgressReporter:
         evaluator_runs.extend(runs)
         evaluator_scores.extend(scores)
 
-        spec = self._update_eval_run_spec(
-            assertion_runs=evaluator_runs,
-            evaluator_scores=evaluator_scores,
-            eval_run_id=sw_progress_item.eval_run_id,
-            execution_time=sw_progress_item.agent_execution_time,
-            actual_output=sw_progress_item.agent_output,
-        )
+        # Use the appropriate spec method based on evaluation type
+        if is_coded:
+            spec = self._update_coded_eval_run_spec(
+                evaluator_runs=evaluator_runs,
+                evaluator_scores=evaluator_scores,
+                eval_run_id=sw_progress_item.eval_run_id,
+                execution_time=sw_progress_item.agent_execution_time,
+                actual_output=sw_progress_item.agent_output,
+                is_coded=is_coded,
+            )
+        else:
+            spec = self._update_eval_run_spec(
+                assertion_runs=evaluator_runs,
+                evaluator_scores=evaluator_scores,
+                eval_run_id=sw_progress_item.eval_run_id,
+                execution_time=sw_progress_item.agent_execution_time,
+                actual_output=sw_progress_item.agent_output,
+                is_coded=is_coded,
+            )
 
         await self._client.request_async(
             method=spec.method,
@@ -311,9 +328,12 @@ class StudioWebProgressReporter:
         self,
         eval_set_run_id: str,
         evaluator_scores: dict[str, float],
+        is_coded: bool = False,
     ):
         """Update the evaluation set run status to complete."""
-        spec = self._update_eval_set_run_spec(eval_set_run_id, evaluator_scores)
+        spec = self._update_eval_set_run_spec(
+            eval_set_run_id, evaluator_scores, is_coded
+        )
         await self._client.request_async(
             method=spec.method,
             url=spec.endpoint,
@@ -332,12 +352,15 @@ class StudioWebProgressReporter:
             is_coded = self._is_coded_evaluator(payload.evaluators)
             self.is_coded_eval[payload.execution_id] = is_coded
 
-            eval_set_run_id = await self.create_eval_set_run(
-                eval_set_id=payload.eval_set_id,
-                agent_snapshot=self._extract_agent_snapshot(payload.entrypoint),
-                no_of_evals=payload.no_of_evals,
-                evaluators=payload.evaluators,
-            )
+            eval_set_run_id = payload.eval_set_run_id
+            if not eval_set_run_id:
+                eval_set_run_id = await self.create_eval_set_run_sw(
+                    eval_set_id=payload.eval_set_id,
+                    agent_snapshot=self._extract_agent_snapshot(payload.entrypoint),
+                    no_of_evals=payload.no_of_evals,
+                    evaluators=payload.evaluators,
+                    is_coded=is_coded,
+                )
             self.eval_set_run_ids[payload.execution_id] = eval_set_run_id
             current_span = trace.get_current_span()
             if current_span.is_recording():
@@ -353,12 +376,16 @@ class StudioWebProgressReporter:
     async def handle_create_eval_run(self, payload: EvalRunCreatedEvent) -> None:
         try:
             if eval_set_run_id := self.eval_set_run_ids.get(payload.execution_id):
+                # Get the is_coded flag for this execution
+                is_coded = self.is_coded_eval.get(payload.execution_id, False)
                 eval_run_id = await self.create_eval_run(
-                    payload.eval_item, eval_set_run_id
+                    payload.eval_item, eval_set_run_id, is_coded
                 )
                 if eval_run_id:
                     self.eval_run_ids[payload.execution_id] = eval_run_id
-                    logger.debug(f"Created eval run with ID: {eval_run_id}")
+                    logger.debug(
+                        f"Created eval run with ID: {eval_run_id} (coded={is_coded})"
+                    )
             else:
                 logger.warning("Cannot create eval run: eval_set_run_id not available")
 
@@ -419,11 +446,16 @@ class StudioWebProgressReporter:
     async def handle_update_eval_set_run(self, payload: EvalSetRunUpdatedEvent) -> None:
         try:
             if eval_set_run_id := self.eval_set_run_ids.get(payload.execution_id):
+                # Get the is_coded flag for this execution
+                is_coded = self.is_coded_eval.get(payload.execution_id, False)
                 await self.update_eval_set_run(
                     eval_set_run_id,
                     payload.evaluator_scores,
+                    is_coded=is_coded,
+                )
+                logger.debug(
+                    f"Updated eval set run with ID: {eval_set_run_id} (coded={is_coded})"
                 )
-                logger.debug(f"Updated eval set run with ID: {eval_set_run_id}")
             else:
                 logger.warning(
                     "Cannot update eval set run: eval_set_run_id not available"
@@ -448,6 +480,24 @@ class StudioWebProgressReporter:
 
         logger.debug("StudioWeb progress reporter subscribed to evaluation events")
 
+    def _serialize_justification(self, justification: Any) -> str | None:
+        """Serialize justification to JSON string for API compatibility.
+
+        Args:
+            justification: The justification object which could be None, a BaseModel,
+                          a string, or any other JSON-serializable object
+
+        Returns:
+            JSON string representation or None if justification is None
+        """
+        if justification is None:
+            return None
+        if hasattr(justification, "model_dump"):
+            return json.dumps(justification.model_dump())
+        if not isinstance(justification, str):
+            return json.dumps(justification)
+        return justification
+
     def _extract_agent_snapshot(self, entrypoint: str) -> StudioWebAgentSnapshot:
         try:
             project_config = get_project_config(os.getcwd())
@@ -486,18 +536,36 @@ class StudioWebProgressReporter:
         usage_metrics = self._extract_usage_from_spans(spans)
 
         for eval_result in eval_results:
+            # Skip results for evaluators not in the provided dict
+            # (happens when processing mixed coded/legacy eval sets)
+            if eval_result.evaluator_id not in evaluators:
+                continue
+
+            # Legacy API expects evaluatorId as GUID, convert string to GUID
+            try:
+                uuid.UUID(eval_result.evaluator_id)
+                evaluator_id_value = eval_result.evaluator_id
+            except ValueError:
+                # Generate deterministic UUID5 from string
+                evaluator_id_value = str(
+                    uuid.uuid5(uuid.NAMESPACE_DNS, eval_result.evaluator_id)
+                )
+
+            # Convert BaseModel justification to JSON string for API compatibility
+            justification = self._serialize_justification(eval_result.result.details)
+
             evaluator_scores_list.append(
                 {
                     "type": eval_result.result.score_type.value,
                     "value": eval_result.result.score,
-                    "justification": eval_result.result.details,
-                    "evaluatorId": eval_result.evaluator_id,
+                    "justification": justification,
+                    "evaluatorId": evaluator_id_value,
                 }
             )
             assertion_runs.append(
                 {
                     "status": EvaluationStatus.COMPLETED.value,
-                    "evaluatorId": eval_result.evaluator_id,
+                    "evaluatorId": evaluator_id_value,
                     "completionMetrics": {
                         "duration": int(eval_result.result.evaluation_time)
                         if eval_result.result.evaluation_time
@@ -536,11 +604,19 @@ class StudioWebProgressReporter:
         usage_metrics = self._extract_usage_from_spans(spans)
 
         for eval_result in eval_results:
+            # Skip results for evaluators not in the provided dict
+            # (happens when processing mixed coded/legacy eval sets)
+            if eval_result.evaluator_id not in evaluators:
+                continue
+
+            # Convert BaseModel justification to JSON string for API compatibility
+            justification = self._serialize_justification(eval_result.result.details)
+
             evaluator_scores_list.append(
                 {
                     "type": eval_result.result.score_type.value,
                     "value": eval_result.result.score,
-                    "justification": eval_result.result.details,
+                    "justification": justification,
                     "evaluatorId": eval_result.evaluator_id,
                 }
             )
@@ -553,7 +629,7 @@ class StudioWebProgressReporter:
                             "type": eval_result.result.score_type.value,
                             "value": eval_result.result.score,
                         },
-                        "justification": eval_result.result.details,
+                        "justification": justification,
                     },
                     "completionMetrics": {
                         "duration": int(eval_result.result.evaluation_time)
@@ -575,17 +651,20 @@ class StudioWebProgressReporter:
         eval_run_id: str,
         actual_output: dict[str, Any],
         execution_time: float,
+        is_coded: bool = False,
     ) -> RequestSpec:
+        # For legacy evaluations, endpoint is without /coded
+        endpoint_suffix = "coded/" if is_coded else ""
         return RequestSpec(
             method="PUT",
             endpoint=Endpoint(
-                f"{self._get_endpoint_prefix()}execution/agents/{self._project_id}/coded/evalRun"
+                f"{self._get_endpoint_prefix()}execution/agents/{self._project_id}/{endpoint_suffix}evalRun"
             ),
             json={
                 "evalRunId": eval_run_id,
                 "status": EvaluationStatus.COMPLETED.value,
                 "result": {
-                    "output": {"content": {**actual_output}},
+                    "output": {**actual_output},
                     "evaluatorScores": evaluator_scores,
                 },
                 "completionMetrics": {"duration": int(execution_time)},
@@ -601,18 +680,21 @@ class StudioWebProgressReporter:
         eval_run_id: str,
         actual_output: dict[str, Any],
         execution_time: float,
+        is_coded: bool = False,
     ) -> RequestSpec:
         """Create update spec for coded evaluators."""
+        # For coded evaluations, endpoint has /coded
+        endpoint_suffix = "coded/" if is_coded else ""
         return RequestSpec(
             method="PUT",
             endpoint=Endpoint(
-                f"{self._get_endpoint_prefix()}execution/agents/{self._project_id}/coded/evalRun"
+                f"{self._get_endpoint_prefix()}execution/agents/{self._project_id}/{endpoint_suffix}evalRun"
             ),
             json={
                 "evalRunId": eval_run_id,
                 "status": EvaluationStatus.COMPLETED.value,
                 "result": {
-                    "output": {"content": {**actual_output}},
+                    "output": {**actual_output},
                     "scores": evaluator_scores,
                 },
                 "completionMetrics": {"duration": int(execution_time)},
@@ -622,11 +704,24 @@ class StudioWebProgressReporter:
         )
 
     def _create_eval_run_spec(
-        self, eval_item: AnyEvaluationItem, eval_set_run_id: str
+        self, eval_item: AnyEvaluationItem, eval_set_run_id: str, is_coded: bool = False
     ) -> RequestSpec:
+        # Legacy API expects eval IDs as GUIDs, coded accepts strings
+        # Convert string IDs to deterministic GUIDs for legacy
+        if is_coded:
+            eval_item_id = eval_item.id
+        else:
+            # Try to parse as GUID, if it fails, generate deterministic GUID from string
+            try:
+                uuid.UUID(eval_item.id)
+                eval_item_id = eval_item.id
+            except ValueError:
+                # Generate deterministic UUID5 from string
+                eval_item_id = str(uuid.uuid5(uuid.NAMESPACE_DNS, eval_item.id))
+
         # Build eval snapshot based on evaluation item type
         eval_snapshot = {
-            "id": eval_item.id,
+            "id": eval_item_id,
             "name": eval_item.name,
             "inputs": eval_item.inputs,
         }
@@ -638,10 +733,12 @@ class StudioWebProgressReporter:
         else:
             eval_snapshot["expectedOutput"] = eval_item.expected_output
 
+        # For legacy evaluations, endpoint is without /coded
+        endpoint_suffix = "coded/" if is_coded else ""
         return RequestSpec(
             method="POST",
             endpoint=Endpoint(
-                f"{self._get_endpoint_prefix()}execution/agents/{self._project_id}/coded/evalRun"
+                f"{self._get_endpoint_prefix()}execution/agents/{self._project_id}/{endpoint_suffix}evalRun"
             ),
             json={
                 "evalSetRunId": eval_set_run_id,
@@ -656,19 +753,42 @@ class StudioWebProgressReporter:
         eval_set_id: str,
         agent_snapshot: StudioWebAgentSnapshot,
         no_of_evals: int,
+        is_coded: bool = False,
     ) -> RequestSpec:
+        # For legacy evaluations, endpoint is without /coded
+        endpoint_suffix = "coded/" if is_coded else ""
+
+        # Legacy API expects evalSetId as GUID, coded accepts string
+        # Convert string IDs to deterministic GUIDs for legacy
+        if is_coded:
+            eval_set_id_value = eval_set_id
+        else:
+            # Try to parse as GUID, if it fails, generate deterministic GUID from string
+            try:
+                uuid.UUID(eval_set_id)
+                eval_set_id_value = eval_set_id
+            except ValueError:
+                # Generate deterministic UUID5 from string
+                eval_set_id_value = str(uuid.uuid5(uuid.NAMESPACE_DNS, eval_set_id))
+
+        payload = {
+            "agentId": self._project_id,
+            "evalSetId": eval_set_id_value,
+            "agentSnapshot": agent_snapshot.model_dump(by_alias=True),
+            "status": EvaluationStatus.IN_PROGRESS.value,
+            "numberOfEvalsExecuted": no_of_evals,
+        }
+
+        # Add version field for coded evaluations
+        if is_coded:
+            payload["version"] = "1.0"
+
         return RequestSpec(
             method="POST",
             endpoint=Endpoint(
-                f"{self._get_endpoint_prefix()}execution/agents/{self._project_id}/coded/evalSetRun"
+                f"{self._get_endpoint_prefix()}execution/agents/{self._project_id}/{endpoint_suffix}evalSetRun"
             ),
-            json={
-                "agentId": self._project_id,
-                "evalSetId": eval_set_id,
-                "agentSnapshot": agent_snapshot.model_dump(by_alias=True),
-                "status": EvaluationStatus.IN_PROGRESS.value,
-                "numberOfEvalsExecuted": no_of_evals,
-            },
+            json=payload,
             headers=self._tenant_header(),
         )
 
@@ -676,16 +796,34 @@ class StudioWebProgressReporter:
         self,
         eval_set_run_id: str,
         evaluator_scores: dict[str, float],
+        is_coded: bool = False,
     ) -> RequestSpec:
-        evaluator_scores_list = [
-            {"value": avg_score, "evaluatorId": evaluator_id}
-            for evaluator_id, avg_score in evaluator_scores.items()
-        ]
+        # Legacy API expects evaluatorId as GUID, coded accepts string
+        evaluator_scores_list = []
+        for evaluator_id, avg_score in evaluator_scores.items():
+            if is_coded:
+                evaluator_id_value = evaluator_id
+            else:
+                # Convert string to GUID for legacy
+                try:
+                    uuid.UUID(evaluator_id)
+                    evaluator_id_value = evaluator_id
+                except ValueError:
+                    # Generate deterministic UUID5 from string
+                    evaluator_id_value = str(
+                        uuid.uuid5(uuid.NAMESPACE_DNS, evaluator_id)
+                    )
 
+            evaluator_scores_list.append(
+                {"value": avg_score, "evaluatorId": evaluator_id_value}
+            )
+
+        # For legacy evaluations, endpoint is without /coded
+        endpoint_suffix = "coded/" if is_coded else ""
         return RequestSpec(
             method="PUT",
             endpoint=Endpoint(
-                f"{self._get_endpoint_prefix()}execution/agents/{self._project_id}/coded/evalSetRun"
+                f"{self._get_endpoint_prefix()}execution/agents/{self._project_id}/{endpoint_suffix}evalSetRun"
             ),
             json={
                 "evalSetRunId": eval_set_run_id,
