@@ -384,6 +384,7 @@ class UiPathRuntimeContext(BaseModel):
     chat_handler: Optional[UiPathConversationHandler] = None
     is_conversational: Optional[bool] = None
     breakpoints: Optional[List[str] | Literal["*"]] = None
+    intercept_logs: bool = True
 
     model_config = {"arbitrary_types_allowed": True, "extra": "allow"}
 
@@ -631,16 +632,17 @@ class UiPathBaseRuntime(ABC):
 
         # Intercept all stdout/stderr/logs
         # write to file (runtime) or stdout (debug)
-        self.logs_interceptor = LogsInterceptor(
-            min_level=self.context.logs_min_level,
-            dir=self.context.runtime_dir,
-            file=self.context.logs_file,
-            job_id=self.context.job_id,
-            execution_id=self.context.execution_id,
-            is_debug_run=self.is_debug_run(),
-            log_handler=self.context.log_handler,
-        )
-        self.logs_interceptor.setup()
+        if self.context.intercept_logs:
+            self.logs_interceptor = LogsInterceptor(
+                min_level=self.context.logs_min_level,
+                dir=self.context.runtime_dir,
+                file=self.context.logs_file,
+                job_id=self.context.job_id,
+                execution_id=self.context.execution_id,
+                is_debug_run=self.is_debug_run(),
+                log_handler=self.context.log_handler,
+            )
+            self.logs_interceptor.setup()
 
         logger.debug(f"Starting runtime with job id: {self.context.job_id}")
 
