@@ -1,6 +1,7 @@
 import json
 import logging
 from typing import Any, Dict, List, Optional
+from urllib.parse import parse_qsl, quote, urlsplit
 
 from httpx import Response
 
@@ -60,24 +61,77 @@ class ConnectionsService(BaseService):
         hide_output=True,
     )
     def metadata(
-        self, element_instance_id: int, tool_path: str, schema_mode: bool = True
+        self,
+        element_instance_id: int,
+        connector_key: str,
+        tool_path: str,
+        parameters: Optional[Dict[str, str]] = None,
+        schema_mode: bool = True,
+        max_jit_depth: int = 5,
     ) -> ConnectionMetadata:
         """Synchronously retrieve connection API metadata.
 
-        This method fetches the metadata for a connection,
-        which can be used to establish communication with an external service.
+        This method fetches the metadata for a connection. When parameters are provided,
+        it automatically fetches JIT (Just-In-Time) metadata for cascading fields in a loop,
+        following action URLs up to a maximum depth.
 
         Args:
             element_instance_id (int): The element instance ID of the connection.
+            connector_key (str): The connector key (e.g., 'uipath-atlassian-jira', 'uipath-slack').
             tool_path (str): The tool path to retrieve metadata for.
+            parameters (Optional[Dict[str, str]]): Parameter values. When provided, triggers
+                automatic JIT fetching for cascading fields.
             schema_mode (bool): Whether or not to represent the output schema in the response fields.
+            max_jit_depth (int): The maximum depth of the JIT resolution loop.
 
         Returns:
             ConnectionMetadata: The connection metadata.
+
+        Examples:
+            >>> metadata = sdk.connections.metadata(
+            ...     element_instance_id=123,
+            ...     connector_key="uipath-atlassian-jira",
+            ...     tool_path="Issue",
+            ...     parameters={"projectId": "PROJ-123"}  # Optional
+            ... )
         """
-        spec = self._metadata_spec(element_instance_id, tool_path, schema_mode)
-        response = self.request(spec.method, url=spec.endpoint, headers=spec.headers)
-        return ConnectionMetadata.model_validate(response.json())
+        spec = self._metadata_spec(
+            element_instance_id, connector_key, tool_path, schema_mode
+        )
+        response = self.request(
+            spec.method, url=spec.endpoint, params=spec.params, headers=spec.headers
+        )
+        data = response.json()
+        metadata = ConnectionMetadata.model_validate(data)
+
+        last_action_url = None
+        depth = 0
+
+        while (
+            parameters
+            and (action_url := self._get_jit_action_url(metadata))
+            and depth < max_jit_depth
+        ):
+            # Stop if we're about to call the same URL template again
+            if action_url == last_action_url:
+                break
+
+            last_action_url = action_url
+            depth += 1
+
+            jit_spec = self._metadata_jit_spec(
+                element_instance_id, action_url, parameters, schema_mode
+            )
+            jit_response = self.request(
+                jit_spec.method,
+                url=jit_spec.endpoint,
+                params=jit_spec.params,
+                headers=jit_spec.headers,
+            )
+            data = jit_response.json()
+            metadata = ConnectionMetadata.model_validate(data)
+
+        return metadata
 
     @traced(name="connections_list", run_type="uipath")
     def list(
@@ -217,26 +271,77 @@ class ConnectionsService(BaseService):
         hide_output=True,
     )
     async def metadata_async(
-        self, element_instance_id: int, tool_path: str, schema_mode: bool = True
+        self,
+        element_instance_id: int,
+        connector_key: str,
+        tool_path: str,
+        parameters: Optional[Dict[str, str]] = None,
+        schema_mode: bool = True,
+        max_jit_depth: int = 5,
     ) -> ConnectionMetadata:
         """Asynchronously retrieve connection API metadata.
 
-        This method fetches the metadata for a connection,
-        which can be used to establish communication with an external service.
+        This method fetches the metadata for a connection. When parameters are provided,
+        it automatically fetches JIT (Just-In-Time) metadata for cascading fields in a loop,
+        following action URLs up to a maximum depth.
 
         Args:
             element_instance_id (int): The element instance ID of the connection.
+            connector_key (str): The connector key (e.g., 'uipath-atlassian-jira', 'uipath-slack').
             tool_path (str): The tool path to retrieve metadata for.
+            parameters (Optional[Dict[str, str]]): Parameter values. When provided, triggers
+                automatic JIT fetching for cascading fields.
             schema_mode (bool): Whether or not to represent the output schema in the response fields.
+            max_jit_depth (int): The maximum depth of the JIT resolution loop.
 
         Returns:
             ConnectionMetadata: The connection metadata.
+
+        Examples:
+            >>> metadata = await sdk.connections.metadata_async(
+            ...     element_instance_id=123,
+            ...     connector_key="uipath-atlassian-jira",
+            ...     tool_path="Issue",
+            ...     parameters={"projectId": "PROJ-123"}  # Optional
+            ... )
         """
-        spec = self._metadata_spec(element_instance_id, tool_path, schema_mode)
-        response = await self.request_async(
-            spec.method, url=spec.endpoint, headers=spec.headers
+        spec = self._metadata_spec(
+            element_instance_id, connector_key, tool_path, schema_mode
         )
-        return ConnectionMetadata.model_validate(response.json())
+        response = await self.request_async(
+            spec.method, url=spec.endpoint, params=spec.params, headers=spec.headers
+        )
+        data = response.json()
+        metadata = ConnectionMetadata.model_validate(data)
+
+        last_action_url = None
+        depth = 0
+
+        while (
+            parameters
+            and (action_url := self._get_jit_action_url(metadata))
+            and depth < max_jit_depth
+        ):
+            # Stop if we're about to call the same URL template again
+            if action_url == last_action_url:
+                break
+
+            last_action_url = action_url
+            depth += 1
+
+            jit_spec = self._metadata_jit_spec(
+                element_instance_id, action_url, parameters, schema_mode
+            )
+            jit_response = await self.request_async(
+                jit_spec.method,
+                url=jit_spec.endpoint,
+                params=jit_spec.params,
+                headers=jit_spec.headers,
+            )
+            data = jit_response.json()
+            metadata = ConnectionMetadata.model_validate(data)
+
+        return metadata
 
     @traced(
         name="connections_retrieve_token",
@@ -377,9 +482,13 @@ class ConnectionsService(BaseService):
         )
 
     def _metadata_spec(
-        self, element_instance_id: int, tool_path: str, schema_mode: bool
+        self,
+        element_instance_id: int,
+        connector_key: str,
+        tool_path: str,
+        schema_mode: bool,
     ) -> RequestSpec:
-        metadata_endpoint_url = f"/elements_/v3/element/instances/{element_instance_id}/elements/{tool_path}/metadata"
+        metadata_endpoint_url = f"/elements_/v3/element/instances/{element_instance_id}/elements/{connector_key}/objects/{tool_path}/metadata"
         return RequestSpec(
             method="GET",
             endpoint=Endpoint(metadata_endpoint_url),
@@ -390,6 +499,54 @@ class ConnectionsService(BaseService):
             },
         )
 
+    def _metadata_jit_spec(
+        self,
+        element_instance_id: int,
+        dynamic_path: str,
+        parameters: Dict[str, str],
+        schema_mode: bool,
+    ) -> RequestSpec:
+        """Build request spec for JIT metadata with dynamic path parameter substitution.
+
+        For example, if the dynamic path is "elements/jira/projects/{projectId}/issues", and the parameters
+        are {"projectId": "PROJ-123"}, the resolved path will be "elements/jira/projects/PROJ-123/issues".
+        """
+        for key, value in parameters.items():
+            dynamic_path = dynamic_path.replace(
+                f"{{{key}}}", quote(str(value), safe="")
+            )
+        split = urlsplit(dynamic_path.lstrip("/"))
+        query_params = dict(parse_qsl(split.query))
+
+        return RequestSpec(
+            method="GET",
+            endpoint=Endpoint(
+                f"/elements_/v3/element/instances/{element_instance_id}/{split.path}"
+            ),
+            params=query_params,
+            headers={
+                "accept": "application/schema+json"
+                if schema_mode
+                else "application/json"
+            },
+        )
+
+    def _get_jit_action_url(
+        self, connection_metadata: ConnectionMetadata
+    ) -> Optional[str]:
+        """Return the URL of the JIT action that should be triggered dynamically."""
+        if "method" not in connection_metadata.metadata:
+            return None
+
+        methods = connection_metadata.metadata["method"]
+        actions = [
+            action
+            for method_data in methods.values()
+            for action in method_data.get("design", {}).get("actions", [])
+            if action.get("actionType") == "api"
+        ]
+        return actions[0].get("apiConfiguration", {}).get("url") if actions else None
+
     def _retrieve_token_spec(
         self, key: str, token_type: ConnectionTokenType = ConnectionTokenType.DIRECT
     ) -> RequestSpec:
