@@ -1,5 +1,5 @@
+from ._bindings import get_inferred_bindings_names, infer_bindings
 from ._endpoint import Endpoint
-from ._infer_bindings import get_inferred_bindings_names, infer_bindings
 from ._logs import setup_logging
 from ._request_override import header_folder
 from ._request_spec import RequestSpec
