@@ -115,7 +115,10 @@ class TestAuth:
                 "tenants": [{"name": "DefaultTenant", "id": "tenant-id"}],
                 "organization": {"name": "DefaultOrg", "id": "org-id"},
             }
-            mock_portal_service.return_value.__enter__.return_value.select_tenant.return_value = expected_select_tenant_return
+            mock_portal_service.return_value.__enter__.return_value._select_tenant.return_value = {
+                "tenant_id": "tenant-id",
+                "organization_id": "org-id",
+            }
 
             with runner.isolated_filesystem():
                 for key, value in env_vars.items():
@@ -160,10 +163,7 @@ class TestAuth:
                 "uipath._cli._auth._auth_service.PortalService"
             ) as mock_portal_service,
             patch(
-                "uipath._cli._auth._auth_service.select_tenant"
-            ) as mock_select_tenant,
-            patch(
-                "uipath._cli._auth._url_utils.get_base_url",
+                "uipath._cli._auth._url_utils.resolve_domain",
                 return_value="https://alpha.uipath.com",
             ),
         ):
@@ -171,13 +171,19 @@ class TestAuth:
                 return_value={"access_token": "test_token"}
             )
 
-            mock_portal_service.return_value.__enter__.return_value.get_tenants_and_organizations.return_value = {
+            portal = mock_portal_service.return_value.__enter__.return_value
+            portal.get_tenants_and_organizations.return_value = {
                 "tenants": [
                     {"name": "MyTenantName", "id": "tenant-id"},
                     {"name": "OtherTenant", "id": "other-id"},
                 ],
                 "organization": {"name": "MyOrg", "id": "org-id"},
             }
+            portal.resolve_tenant_info.return_value = {
+                "tenant_id": "tenant-id",
+                "organization_id": "org-id",
+            }
+            portal.selected_tenant = "MyTenantName"
 
             result = runner.invoke(
                 cli, ["auth", "--alpha", "--tenant", "MyTenantName", "--force"]
@@ -186,7 +192,4 @@ class TestAuth:
             assert result.exit_code == 0, result.output
             mock_open.assert_called_once()
 
-            assert not mock_select_tenant.called
-
-            portal = mock_portal_service.return_value.__enter__.return_value
-            assert portal.get_tenants_and_organizations.called
+            portal.resolve_tenant_info.assert_called_once_with("MyTenantName")
