@@ -1,5 +1,6 @@
 import importlib
 from functools import wraps
+from pathlib import Path
 
 import pytest
 
@@ -46,6 +47,11 @@ def execution_context(monkeypatch: pytest.MonkeyPatch) -> ExecutionContext:
     return ExecutionContext()
 
 
+@pytest.fixture
+def tests_data_path() -> Path:
+    return Path(__file__).resolve().parent / "tests_data"
+
+
 @pytest.fixture(autouse=True)
 def mock_tracer():
     def mock_tracer_impl(**kwargs):
